<?php
/**
 * About setup
 *
 * @package News-Base
 */

if ( ! function_exists( 'news_base_about_setup' ) ) :

	/**
	 * About setup.
	 *
	 * @since 1.0.0
	 */
	function news_base_about_setup() {

		$config = array(
		// Menu name under Appearance.
		'menu_name'               => esc_html__( 'News Base Info', 'news-base' ),
		// Page title.
		'page_name'               => esc_html__( 'News Base Info', 'news-base' ),
		/* translators: Main welcome title */
		'welcome_title'         => sprintf( esc_html__( 'Welcome to %s! - Version ', 'news-base' ), 'News Base' ),
		// Main welcome content
			// Welcome content.
			'welcome_content' => sprintf( esc_html__( '%1$s is now installed and ready to use. We want to make sure you have the best experience using the theme and that is why we gathered here all the necessary information for you. Thanks for using our theme!', 'news-base' ), 'News Base Pro' ),

			// Tabs.
			'tabs' => array(
				'getting_started' => esc_html__( 'Getting Started', 'news-base' ),
				'recommended_actions' => esc_html__( 'Recommended Actions', 'news-base' ),
				'useful_plugins'  => esc_html__( 'Useful Plugins', 'news-base' ),
				'free_pro'  => esc_html__( 'Free Vs Pro', 'news-base' ),
				),

			// Quick links.
			'quick_links' => array(
                'theme_url' => array(
                    'text' => esc_html__( 'Theme Details', 'news-base' ),
                    'url'  => 'https://thememattic.com/theme/news-base/',
                ),
                'demo_url' => array(
                    'text' => esc_html__( 'View Demo', 'news-base' ),
                    'url'  => 'https://demo.thememattic.com/news-base/',
                ),
                'documentation_url' => array(
                    'text'   => esc_html__( 'View Documentation', 'news-base' ),
                    'url'    => 'https://docs.thememattic.com/news-base/',
                    'button' => 'primary',
                ),
            ),

			// Getting started.
			'getting_started' => array(
				'one' => array(
					'title'       => esc_html__( 'Theme Documentation', 'news-base' ),
					'icon'        => 'dashicons dashicons-format-aside',
					'description' => esc_html__( 'Please check our full documentation for detailed information on how to setup and customize the theme.', 'news-base' ),
					'button_text' => esc_html__( 'View Documentation', 'news-base' ),
					'button_url'  => 'https://docs.thememattic.com/news-base/',
					'button_type' => 'primary',
					'is_new_tab'  => true,
					),
				'two' => array(
					'title'       => esc_html__( 'Theme Options', 'news-base' ),
					'icon'        => 'dashicons dashicons-admin-customizer',
					'description' => esc_html__( 'Theme uses Customizer API for theme options. Using the Customizer you can easily customize different aspects of the theme.', 'news-base' ),
					'button_text' => esc_html__( 'Customize', 'news-base' ),
					'button_url'  => wp_customize_url(),
					'button_type' => 'primary',
					),
				'three' => array(
					'title'       => esc_html__( 'Demo Content', 'news-base' ),
					'icon'        => 'dashicons dashicons-layout',
					'description' => sprintf( esc_html__( 'To import sample demo content, %1$s plugin should be installed and activated. After plugin is activated, visit Import Demo Data menu under Appearance.', 'news-base' ), esc_html__( 'One Click Demo Import', 'news-base' ) ),
					),
				'four' => array(
				    'title'       => esc_html__( 'Set Widgets', 'news-base' ),
				    'icon'        => 'dashicons dashicons-tagcloud',
				    'description' => esc_html__( 'Set widgets in your sidebar, Offcanvas as well as footer.', 'news-base' ),
				    'button_text' => esc_html__( 'Add Widgets', 'news-base' ),
				    'button_url'  => admin_url().'/widgets.php',
				    'button_type' => 'link',
				    'is_new_tab'  => true,
				),
				'five' => array(
					'title'       => esc_html__( 'Theme Preview', 'news-base' ),
					'icon'        => 'dashicons dashicons-welcome-view-site',
					'description' => esc_html__( 'You can check out the theme demos for reference to find out what you can achieve using the theme and how it can be customized.', 'news-base' ),
					'button_text' => esc_html__( 'View Demo', 'news-base' ),
					'button_url'  => 'https://demo.thememattic.com/news-base/',
					'button_type' => 'link',
					'is_new_tab'  => true,
					),
                'six' => array(
                    'title'       => esc_html__( 'Contact Support', 'news-base' ),
                    'icon'        => 'dashicons dashicons-sos',
                    'description' => esc_html__( 'Got theme support question or found bug or got some feedbacks? Best place to ask your query is the dedicated Support forum for the theme.', 'news-base' ),
                    'button_text' => esc_html__( 'Contact Support', 'news-base' ),
                    'button_url'  => 'https://thememattic.com/support/',
                    'button_type' => 'link',
                    'is_new_tab'  => true,
                ),
				),

					'useful_plugins'        => array(
						'description' => esc_html__( 'Theme supports some helpful WordPress plugins to enhance your site. But, please enable only those plugins which you need in your site. For example, enable WooCommerce only if you are using e-commerce.', 'news-base' ),
						'already_activated_message' => esc_html__( 'Already activated', 'news-base' ),
						'version_label' => esc_html__( 'Version: ', 'news-base' ),
						'install_label' => esc_html__( 'Install and Activate', 'news-base' ),
						'activate_label' => esc_html__( 'Activate', 'news-base' ),
						'deactivate_label' => esc_html__( 'Deactivate', 'news-base' ),
						'content'                   => array(
							array(
								'slug' => 'one-click-demo-import'
							),
						),
					),
					// Required actions array.
					'recommended_actions'        => array(
						'install_label' => esc_html__( 'Install and Activate', 'news-base' ),
						'activate_label' => esc_html__( 'Activate', 'news-base' ),
						'deactivate_label' => esc_html__( 'Deactivate', 'news-base' ),
						'content'            => array(
							'one-click-demo-import' => array(
								'title'       => 'One Click Demo Import',
								'description' => __( 'It is only recommended when you need the site as like our demos along with the demo content', 'news-base' ),
								'plugin_slug' => 'one-click-demo-import',
								'id' => 'one-click-demo-import'
							),
						),
					),
			// Free vs pro array.
			'free_pro'                => array(
				'free_theme_name'     => 'News Base',
				'pro_theme_name'      => 'News Base Pro',
				'pro_theme_link'      => 'https://thememattic.com/themes/news-base-pro',
				/* translators: View link */
				'get_pro_theme_label' => sprintf( __( 'Get %s', 'news-base' ), 'News Base Pro' ),
				'features'            => array(
					array(
						'title'       => esc_html__( 'Daring Design for Devoted Readers', 'news-base' ),
						'description' => esc_html__( 'News Base\'s design helps you stand out from the crowd and create an experience that your readers will love and talk about. With a flexible home page you have the chance to easily showcase appealing content with ease.', 'news-base' ),
						'is_in_lite'  => 'true',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Mobile-Ready For All Devices', 'news-base' ),
						'description' => esc_html__( 'News Base makes room for your readers to enjoy your articles on the go, no matter the device their using. We shaped everything to look amazing to your audience.', 'news-base' ),
						'is_in_lite'  => 'true',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( '1 Click Demo Import', 'news-base' ),
						'description' => esc_html__( 'In just a few minutes, your site will be ready with exactly the same layout with the demo. All you need to do is just replace sample content with yours to get started.', 'news-base' ),
						'is_in_lite'  => 'true',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Widgetized Sidebars To Keep Attention', 'news-base' ),
						'description' => esc_html__( 'News Base comes with a widget-based flexible system which allows you to add your favourite widgets over the Sidebar as well as on off-canvas too.', 'news-base' ),
						'is_in_lite'  => 'true',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Light & Dark mode in single click', 'news-base' ),
						'description' => esc_html__( 'News Base pro can be switched to dark mode where as News Base free does not has that option', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Multiple Header Layout', 'news-base' ),
						'description' => esc_html__( 'News Base gives you extra ways to showcase your header with miltiple layout option you can change it on the basis of your requirement', 'news-base' ),
						'is_in_lite'  => 'true',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Banner Slider Options', 'news-base' ),
						'description' => esc_html__( 'News Base\'s PRO version comes with more Slider options to display and filter posts. For instance, you can have far more control on setting the source of the posts or how they are displayed, everything to push the content to the right people and promote it by the blink of an eye.', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Flexible Home Page Design', 'news-base' ),
						'description' => esc_html__( 'News Base\'s PRO version has more control available to enable you to place widgets on Footer or Below the Post at the end of your articles.', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Read Time Calculator', 'news-base' ),
						'description' => esc_html__( 'News Base\'s PRO version has a feature to let your viewer know the read time of the standard article you have posted on the basis of words per minute which you can control on your customizer .', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Advance Customizer Options', 'news-base' ),
						'description' => esc_html__( 'Advance control for each element gives you different way of customization and maintained you site as you like and makes you feel different.', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Advance Pagination', 'news-base' ),
						'description' => esc_html__( 'Multiple Option of pagination via customizer can be obtained on your site like Infinite scroll, Ajax Button On Click, Number as well as classical option are available.','news-base' ),
						'is_in_lite'  => 'ture',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Flexible Color Scheme', 'news-base' ),
						'description' => esc_html__( 'Match your unique style in an easy and smart way by using an intuitive interface that you can fine-tune it until it fully represents you and matches your particular blogging needs.','news-base' ),
						'is_in_lite'  => 'ture',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Advanced Typography Settings', 'news-base' ),
						'description' => esc_html__( 'Adjust your fonts by taking advantage of a playground with 600+ fonts varieties you can wisely choose from at any moment.','news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Premium Support and Assistance', 'news-base' ),
						'description' => esc_html__( 'We offer ongoing customer support to help you get things done in due time. This way, you save energy and time, and focus on what brings you happiness. We know our products inside-out and we can lend a hand to help you save resources of all kinds.','news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'Mailchimp and Instagram Feature', 'news-base' ),
						'description' => esc_html__( 'News Base\'s Pro theme has feature of Mailchimp subscription as well as displays your instagram feed images in your site footer.', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
					array(
						'title'       => esc_html__( 'No Credit Footer Link', 'news-base' ),
						'description' => esc_html__( 'You can easily remove the “Theme: News Base by thememattic copyright from the footer area and make the theme yours from start to finish.', 'news-base' ),
						'is_in_lite'  => 'false',
						'is_in_pro'   => 'true',
					),
				),
			),

			);

		News_Base_About::init( $config );
	}

endif;

add_action( 'after_setup_theme', 'news_base_about_setup' );
